.. _core_internal_toplevel:

Core Internals
==============

Some key internal constructs are listed here.

.. currentmodule:: sqlalchemy

.. autoclass:: sqlalchemy.engine.BindTyping
    :members:

.. autoclass:: sqlalchemy.engine.Compiled
    :members:

.. autoclass:: sqlalchemy.engine.interfaces.DBAPIConnection
    :members:
    :undoc-members:

.. autoclass:: sqlalchemy.engine.interfaces.DBAPICursor
    :members:
    :undoc-members:

.. autoclass:: sqlalchemy.engine.interfaces.DBAPIType
    :members:
    :undoc-members:

.. autoclass:: sqlalchemy.sql.compiler.DDLCompiler
    :members:
    :inherited-members:

.. autoclass:: sqlalchemy.engine.default.DefaultDialect
    :members:
    :inherited-members:

.. autoclass:: sqlalchemy.engine.Dialect
    :members:

.. autoclass:: sqlalchemy.engine.default.DefaultExecutionContext
    :members:


.. autoclass:: sqlalchemy.engine.ExecutionContext
    :members:

.. autoclass:: sqlalchemy.sql.compiler.ExpandedState
    :members:


.. autoclass:: sqlalchemy.sql.compiler.GenericTypeCompiler
    :members:
    :inherited-members:


.. autoclass:: sqlalchemy.log.Identified
    :members:


.. autoclass:: sqlalchemy.sql.compiler.IdentifierPreparer
    :members:


.. autoclass:: sqlalchemy.sql.compiler.SQLCompiler
    :members:

.. autoclass:: sqlalchemy.sql.compiler.StrSQLCompiler
    :members:


.. autoclass:: sqlalchemy.engine.AdaptedConnection
    :members:
